<?php

namespace Litepie\Category\Forms;

use Litepie\Form\FormInterpreter;

class Advertisement extends FormInterpreter
{

    /**
     * Sets the form and form elements.
     * @return null.
     */
    public static function setAttributes()
    {

        self::$urls = [
            'new' => [
                'url' => guard_url('category/advertisement/new'),
                'method' => 'GET',
            ],
            'create' => [
                'url' => guard_url('category/advertisement/create'),
                'method' => 'GET',
            ],
            'store' => [
                'url' => guard_url('category/advertisement'),
                'method' => 'POST',
            ],
            'update' => [
                'url' => guard_url('category/advertisement'),
                'method' => 'PUT',
            ],
            'list' => [
                'url' => guard_url('category/advertisement'),
                'method' => 'GET',
            ],
            'delete' => [
                'url' => guard_url('category/advertisement'),
                'method' => 'DELETE',
            ],
        ];
        self::$search = [
            'name' => [
                "type" => 'text',
                "label" => trans('category::category.label.name'),
                "placeholder" => trans('category::category.placeholder.name'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "4",
                "roles" => [],
            ]
        ];
        self::$orderBy = [
            'created_at' => trans('category::category.label.created_at'),
            'name' => trans('category::category.label.name'),
            'status' => trans('category::category.label.status'),
        ];
        self::$groups = [
            'main' => trans('category::category.groups.main'),
            'details' => trans('category::category.groups.details'),
            'images' => trans('category::category.groups.images'),
            'settings' => trans('category::category.groups.settings'),
        ];
        self::$list = [
            [
                'key' => "ref",
                'label' => trans('category::category.label.ref'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "id",
                'label' => trans('category::category.label.id'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "name",
                'label' => trans('category::category.label.name'),
                'sortable' => 'true',
                'roles' => [],
            ],
            [
                'key' => "status",
                'label' => trans('category::category.label.status'),
                'sortable' => 'true',
                'roles' => [],
            ],
        ];
        self::$fields = [
                'client_id' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('category::advertisement.label.client_id'),
                "placeholder" => trans('category::advertisement.placeholder.client_id'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'category_id' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('category::advertisement.label.category_id'),
                "placeholder" => trans('category::advertisement.placeholder.category_id'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'type' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('category::advertisement.label.type'),
                "placeholder" => trans('category::advertisement.placeholder.type'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'title' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('category::advertisement.label.title'),
                "placeholder" => trans('category::advertisement.placeholder.title'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'details' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('category::advertisement.label.details'),
                "placeholder" => trans('category::advertisement.placeholder.details'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'price' => [
                "element" => 'numeric',
                "type" => 'numeric',
                "label" => trans('category::advertisement.label.price'),
                "placeholder" => trans('category::advertisement.placeholder.price'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'images' => [
                "element" => 'text',
                "type" => 'text',
                "label" => trans('category::advertisement.label.images'),
                "placeholder" => trans('category::advertisement.placeholder.images'),
                "rules" => '',
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'conditions' => [
                "element" => 'radios',
                "type" => 'radios',
                "label" => trans('category::advertisement.label.conditions'),
                "placeholder" => trans('category::advertisement.placeholder.conditions'),
                "rules" => '',
                "options" => function(){
                    return [];
                },
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
            'negotiable' => [
                "element" => 'radios',
                "type" => 'radios',
                "label" => trans('category::advertisement.label.negotiable'),
                "placeholder" => trans('category::advertisement.placeholder.negotiable'),
                "rules" => '',
                "options" => function(){
                    return [];
                },
                "group" => "main",
                "section" => "first",
                "col" => "6",
                "append" => null,
                "prepend" => null,
                "roles" => [],
                "attributes" => [
                    'wrapper' => [],
                    "label" => [],
                    "element" => [],

                ],
            ],
        ];

        return new static();
    }
}
